@@ -1,4 +1,4 @@
-/* $Id: synce-serial-chat.c,v 1.2 2003/07/23 13:12:18 twogood Exp $ */
+/* $Id: synce-serial-chat.c 3078 2007-12-12 07:50:04Z mark_ellis $ */
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
@@ -24,7 +24,7 @@ int main(int argc, char** argv)
 		return 1;
 	}
 
-  openlog("synce-serial-chat", 0, LOG_DAEMON);
+	openlog("synce-serial-chat", 0, LOG_DAEMON);
 	
 	memset(buffer, 0, sizeof(buffer));
 
@@ -44,7 +44,7 @@ int main(int argc, char** argv)
 	if (bytes_left != 0)
 	{
 		syslog(LOG_INFO, "Failed to read last %i bytes. Only %i bytes read: '%s'", 
-        bytes_left, bytes_read_total, buffer);
+		       (int)bytes_left, (int)bytes_read_total, buffer);
 		return 1;
 	}
 
